==> apache-nutch-1.21-src.zip: apache-nutch-1.21/src/java/org/apache/nutch/crawl/SignatureFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nutch.crawl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

// Hadoop imports
import org.apache.hadoop.conf.Configuration;
import org.apache.nutch.util.ObjectCache;

import java.lang.invoke.MethodHandles;

/**
 * Factory class, which instantiates a Signature implementation according to the
 * current Configuration configuration. This newly created instance is cached in
 * the Configuration instance, so that it could be later retrieved.
 * 
 * @author Andrzej Bialecki &lt;ab@getopt.org&gt;
 */
public class SignatureFactory {
  private static final Logger LOG = LoggerFactory
      .getLogger(MethodHandles.lookup().lookupClass());

  private SignatureFactory() {
  } // no public constructor

  /**
   * Return the {@link Signature} implementation for a given 
   * {@link Configuration}, or {@link MD5Signature} by default.
   * @param conf a populated {@link Configuration}
   * @return the {@link Signature} implementation
   */
  public synchronized static Signature getSignature(Configuration conf) {
    String clazz = conf.get("db.signature.class", MD5Signature.class.getName());
    ObjectCache objectCache = ObjectCache.get(conf);
    Signature impl = (Signature) objectCache.getObject(clazz);
    if (impl == null) {
      try {
        LOG.info("Using Signature impl: {}", clazz);
        Class<?> implClass = Class.forName(clazz);
        impl = (Signature) implClass.getConstructor().newInstance();
        impl.setConf(conf);
        objectCache.setObject(clazz, impl);
      } catch (Exception e) {
        throw new RuntimeException("Couldn't create " + clazz, e);
      }
    }
    return impl;
  }
}

==> apache-nutch-2.3.1-src.zip: apache-nutch-2.3.1/src/java/org/apache/nutch/crawl/SignatureFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.crawl;

// Commons Logging imports
import java.util.Collection;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.nutch.storage.WebPage;
import org.apache.nutch.util.ObjectCache;

/**
 * Factory class, which instantiates a Signature implementation according to the
 * current Configuration configuration. This newly created instance is cached in
 * the Configuration instance, so that it could be later retrieved.
 * 
 * @author Andrzej Bialecki &lt;ab@getopt.org&gt;
 */
public class SignatureFactory {
  private static final Logger LOG = LoggerFactory
      .getLogger(SignatureFactory.class);

  private SignatureFactory() {
  } // no public ctor

  /** Return the default Signature implementation. */
  public static Signature getSignature(Configuration conf) {
    String clazz = conf.get("db.signature.class", MD5Signature.class.getName());
    ObjectCache objectCache = ObjectCache.get(conf);
    Signature impl = (Signature) objectCache.getObject(clazz);
    if (impl == null) {
      try {
        LOG.info("Using Signature impl: " + clazz);
        Class<?> implClass = Class.forName(clazz);
        impl = (Signature) implClass.newInstance();
        impl.setConf(conf);
        objectCache.setObject(clazz, impl);
      } catch (Exception e) {
        throw new RuntimeException("Couldn't create " + clazz, e);
      }
    }
    return impl;
  }

  public static Collection<WebPage.Field> getFields(Configuration conf) {
    Signature impl = getSignature(conf);
    return impl.getFields();
  }
}
